# Upstream uses weird versioning convention
%global upstreamver 2.3_1-opensource

Summary:    QIODevice that compresses data streams
Name:       qtiocompressor
Version:    2.3.1
Release:    21%{?dist}
License:    GPLv3 or LGPLv2 with exceptions
URL:        http://qt.nokia.com/products/appdev/add-on-products/catalog/4/Utilities/qtiocompressor/

# The original source was http://get.qt.nokia.com/qt/solutions/lgpl/qtiocompressor-%%{upstreamver}.tar.gz but is unavailable.
# A merge request to reimport this module to qt-solutions is already open at https://codereview.qt-project.org/#/c/58895/
Source0:    https://fale.fedorapeople.org/qtiocompressor/qtiocompressor-%{upstreamver}.tar.gz
# To add qmake support for convenience for packages using this library:
# http://bugreports.qt.nokia.com/browse/QTSOLBUG-119
Source1:    qtiocompressor.prf

# Don't build examples:
Patch0:     qtiocompressor-build.patch
# Use Qt5 library
Patch1:     qtiocompressor-2.3.1_use-qt5-lib.patch

BuildRequires:  qt5-qtbase-devel
BuildRequires:  zlib-devel

%description
The class works on top of a QIODevice subclass, compressing data before it is
written and decompressing it when it is read. Since QtIOCompressor works on
streams, it does not have to see the entire data set before compressing or
decompressing it. This can reduce the memory requirements when working on large
data sets.


%package    devel
Summary:    Development files for %{name}
Requires:   %{name}%{?_isa} = %{version}-%{release}
Requires:   qt5-qtbase-devel

%description    devel
This package contains libraries and header files for developing applications
that use QtIOCompressor.


%prep
%autosetup -p1 -n %{name}-%{upstreamver}


%build
touch .licenseAccepted
# Does not use GNU configure
./configure -library
%{qmake_qt5}
%make_build


%install
# libraries
mkdir -p %{buildroot}%{_qt5_libdir}
cp -a lib/* %{buildroot}%{_qt5_libdir}
chmod 755 %{buildroot}%{_qt5_libdir}/*.so.*.*.*

# headers
mkdir -p %{buildroot}%{_qt5_headerdir}/QtSolutions
cp -a \
    src/qtiocompressor.h \
    src/QtIOCompressor \
    %{buildroot}%{_qt5_headerdir}/QtSolutions

mkdir -p %{buildroot}%{_qt5_libdir}/qt5/mkspecs/features/
cp -a %{SOURCE1} %{buildroot}%{_qt5_libdir}/qt5/mkspecs/features/



%files
%license LGPL_EXCEPTION.txt LICENSE.*
%doc README.TXT
%{_qt5_libdir}/lib*.so.1*


%files devel
%doc doc examples
%{_qt5_libdir}/lib*.so
%{_qt5_headerdir}/QtSolutions/
%{_qt5_libdir}/qt5/mkspecs/features/%{name}.prf


%changelog
* Mon Apr 06 2020 Rex Dieter <rdieter@fedoraproject.org> - 2.3.1-21
- s/qt5-devel/qt5-qtbase-devel/

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sun Oct 21 2018 Robert-André Mauchin <zebob.m@gmail.com> -  2.3.1-17
- Rebuild for Qt5

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Rex Dieter <rdieter@fedoraproject.org> - 2.3.1-11
- use %%qmake_qt4 macro to ensure proper build flags

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 2.3.1-9
- Rebuilt for GCC 5 C++11 ABI change

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Jul 05 2010 Orcan Ogetbil <oget[dot]fedora[at]gmail[dot]com> 2.3.1-1
- Initial build. Spec file based on qtsingleapplication.
